aboutsummaryrefslogtreecommitdiffhomepage
path: root/tools/skiaserve/urlhandlers/UrlHandler.h
diff options
context:
space:
mode:
Diffstat (limited to 'tools/skiaserve/urlhandlers/UrlHandler.h')
-rw-r--r--tools/skiaserve/urlhandlers/UrlHandler.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/tools/skiaserve/urlhandlers/UrlHandler.h b/tools/skiaserve/urlhandlers/UrlHandler.h
index 1536ef33c7..e86e7fca90 100644
--- a/tools/skiaserve/urlhandlers/UrlHandler.h
+++ b/tools/skiaserve/urlhandlers/UrlHandler.h
@@ -112,9 +112,9 @@ public:
};
/*
* Returns a json descripton of all the batches in the image
*/
-class BatchesHandler : public UrlHandler {
+class OpsHandler : public UrlHandler {
public:
bool canHandle(const char* method, const char* url) override;
int handle(Request* request, MHD_Connection* connection,
@@ -123,9 +123,9 @@ public:
};
/*
- * Enables drawing of batch bounds
+ * Enables drawing of gpu op bounds
*/
-class BatchBoundsHandler : public UrlHandler {
+class OpBoundsHandler : public UrlHandler {
public:
bool canHandle(const char* method, const char* url) override;
int handle(Request* request, MHD_Connection* connection,
@@ -112,9 +112,9 @@ public:
};
/*
- * Returns a json descripton of all the batches in the image
+ * Returns a json descripton of all the GPU ops in the image
*/